# LANscape
A python based local network scanner.

![screenshot](https://github.com/mdennis281/py-lanscape/raw/main/static/img/readme1.png)


# Local Run
```sh
pip install lanscape
py -m lanscape
```

